*******
Magnopy
*******

Magnopy is a Python package for the magnon-related properties:

* Ground state energy
* Energy minimization
* Linear Spin Wave theory and what comes from it

Please visit an extensive documentation on `magnopy.org <https://magnopy.org>`_ to find
out more.

Installation
============

To install magnopy run (you may need to use ``pip3``):

.. code-block:: console

    pip install magnopy

Usage
=====

There are two ways to use magnopy:

* As a blackbox via `command line interface <https://docs.magnopy.org/en/latest/user-guide/index.html>`_
* As a `Python library <https://docs.magnopy.org/en/latest/user-guide/index.html>`_

User support
============

There are two ways to ask for help or give feedback

*   `Forum at google groups <https://groups.google.com/g/magnopy>`_

    You may send email directly to magnopy@googlegroups.com

*   `Github discussions <https://github.com/magnopy/magnopy/discussions>`_

    You may need to create an account at github to post a question.

Both are monitored by the authors, choose the one you prefer.

Development
===========

We welcome contributions to magnopy. If you would like to contribute, please
consult the `development guide <https://docs.magnopy.org/en/latest/development/index.html>`_
or contact the authors of the project.
